@@ -8,6 +8,7 @@
     :copyright: (c) 2013 by Hsiaoming Yang.
 """
 
+import logging
 import oauthlib.oauth1
 import oauthlib.oauth2
 from functools import wraps
@@ -21,7 +22,7 @@ try:
 except ImportError:
     from urllib import request as http
     from urllib.parse import urljoin, urlparse
-from .utils import log
+log = logging.getLogger('flask_oauthlib')
 
 
 __all__ = ('OAuth', 'OAuthRemoteApp', 'OAuthResponse', 'OAuthException')
@@ -297,10 +298,17 @@ class OAuthRemoteApp(object):
                 return default
             return attr
         app = self.oauth.app or current_app
-        config = app.config[self.app_key]
+        if self.app_key in app.config:
+            # works with dict config
+            config = app.config[self.app_key]
+            if default is not False:
+                return config.get(key, default)
+            return config[key]
+        # works with plain text config
+        config_key = "%s_%s" % (self.app_key, key.upper())
         if default is not False:
-            return config.get(key, default)
-        return config[key]
+            return app.config.get(config_key, default)
+        return app.config[config_key]
 
     def make_client(self, token=None):
         # request_token_url is for oauth1
