@@ -9,6 +9,7 @@
 """
 
 import os
+import logging
 import datetime
 from functools import wraps
 from flask import request, url_for
@@ -18,10 +19,12 @@ from werkzeug.utils import import_string
 from oauthlib import oauth2
 from oauthlib.oauth2 import RequestValidator, Server
 from oauthlib.common import to_unicode
-from ..utils import extract_params, log, decode_base64, create_response
+from ..utils import extract_params, decode_base64, create_response
 
 __all__ = ('OAuth2Provider', 'OAuth2RequestValidator')
 
+log = logging.getLogger('flask_oauthlib')
+
 
 class OAuth2Provider(object):
     """Provide secure services using OAuth2.
@@ -459,7 +462,7 @@ class OAuth2RequestValidator(RequestValidator):
 
         .. _`Section 3.2.1`: http://tools.ietf.org/html/rfc6749#section-3.2.1
         """
-        auth = request.headers.get('Http-Authorization', None)
+        auth = request.headers.get('Authorization', None)
         log.debug('Authenticate client %r', auth)
         if auth:
             try:
